@@ -3,7 +3,7 @@ from AOT_biomaps.AOT_Recon.ReconEnums import PotentialType
 from AOT_biomaps.AOT_Recon.AOT_PotentialFunctions.Quadratic import _Omega_QUADRATIC_CPU, _Omega_QUADRATIC_GPU
 from AOT_biomaps.AOT_Recon.AOT_PotentialFunctions.RelativeDifferences import _Omega_RELATIVE_DIFFERENCE_CPU, _Omega_RELATIVE_DIFFERENCE_GPU
 from AOT_biomaps.AOT_Recon.AOT_PotentialFunctions.Huber import _Omega_HUBER_PIECEWISE_CPU, _Omega_HUBER_PIECEWISE_GPU
-from AOT_biomaps.AOT_Recon.ReconTools import _build_adjacency_sparse_CPU, _build_adjacency_sparse_GPU
+from AOT_biomaps.AOT_Recon.ReconTools import _build_adjacency_sparse
 from AOT_biomaps.Config import config
 
 import numpy as np
@@ -46,7 +46,7 @@ def _MAPEM_CPU_STOP(SMatrix, y, Omega, numIterations, beta, delta, gamma, sigma,
         results = [I_0.numpy()]
         previous = -np.inf
         normalization_factor = SMatrix.sum(dim=(0, 3)).reshape(-1)
-        adj_index, adj_values = _build_adjacency_sparse_CPU(Z, X)
+        adj_index, adj_values = _build_adjacency_sparse(Z, X)
 
         if Omega == PotentialType.HUBER_PIECEWISE:
             description = f"AOT-BioMaps -- Bayesian Reconstruction Tomography: MAP-EM (Sparse HUBER β:{beta:.4f}, δ:{delta:.4f}) + STOP condition (penalized log-likelihood) ---- {'WITH' if withTumor else 'WITHOUT'} TUMOR ---- processing on single CPU ----"
@@ -132,7 +132,7 @@ def _MAPEM_GPU_STOP(SMatrix, y, Omega, numIterations, beta, delta, gamma, sigma,
         normalization_factor_flat = normalization_factor.reshape(-1)
         previous = -np.inf
         nb_false_successive = 0
-        adj_index, adj_values = _build_adjacency_sparse_GPU(Z, X, device=device)
+        adj_index, adj_values = _build_adjacency_sparse(Z, X, device=device)
 
         if Omega == PotentialType.HUBER_PIECEWISE:
             description = f"AOT-BioMaps -- Bayesian Reconstruction Tomography: MAP-EM (Sparse HUBER β:{beta:.4f}, δ:{delta:.4f}) + STOP condition (penalized log-likelihood) ---- {'WITH' if withTumor else 'WITHOUT'} TUMOR ---- processing on single GPU no.{torch.cuda.current_device()} ----"
@@ -223,7 +223,7 @@ def _MAPEM_CPU(SMatrix, y, Omega, numIterations, beta, delta, gamma, sigma, isSa
         I_reconMatrix = [theta_0.copy()]
         normalization_factor = SMatrix.sum(axis=(0, 3))
         normalization_factor_flat = normalization_factor.reshape(-1)
-        adj_index, adj_values = _build_adjacency_sparse_CPU(Z, X)
+        adj_index, adj_values = _build_adjacency_sparse(Z, X)
 
         if Omega == PotentialType.HUBER_PIECEWISE:
             description = f"AOT-BioMaps -- Bayesian Reconstruction Tomography: MAP-EM (Sparse HUBER β:{beta:.4f}, δ:{delta:.4f}) ---- {'WITH' if withTumor else 'WITHOUT'} TUMOR ---- processing on single CPU ----"
@@ -302,7 +302,7 @@ def _MAPEM_GPU(SMatrix, y, Omega, numIterations, beta, delta, gamma, sigma, isSa
         I_reconMatrix = [theta_0.cpu().numpy()]
         normalization_factor = A_matrix_torch.sum(dim=(0, 3))
         normalization_factor_flat = normalization_factor.reshape(-1)
-        adj_index, adj_values = _build_adjacency_sparse_GPU(Z, X, device=device)
+        adj_index, adj_values = _build_adjacency_sparse(Z, X, device=device)
 
         if Omega == PotentialType.HUBER_PIECEWISE:
             description = f"AOT-BioMaps -- Bayesian Reconstruction Tomography: MAP-EM (Sparse HUBER β:{beta:.4f}, δ:{delta:.4f}) ---- {'WITH' if withTumor else 'WITHOUT'} TUMOR ---- processing on single GPU no.{torch.cuda.current_device()} ----"
