@@ -610,7 +610,7 @@ class AlgebraicRecon(Recon):
         print(f"Reconstruction results loaded from {os.path.join(self.saveDir, 'results')}")
 
     def normalizeSMatrix(self):
-        self.SMatrix = self.SMatrix / (self.experiment.params.acoustic['voltage']*self.experiment.params.acoustic['sensitivity'])
+        self.SMatrix = self.SMatrix / (float(self.experiment.params.acoustic['voltage'])*float(self.experiment.params.acoustic['sensitivity']))  
 
     # PRIVATE METHODS
 
@@ -651,7 +651,7 @@ class AlgebraicRecon(Recon):
 
         # Check if input file exists
         if not os.path.isfile(f"{self.saveDir}/{fileName}"):
-            self.experiment._saveAOsignals_Castor(self.saveDir)
+            self.experiment.saveAOsignals_Castor(self.saveDir)
         # Check if system matrix directory exists
         elif not os.path.isdir(smatrix):
             os.mkdir(smatrix)
